@@ -1,4 +1,4 @@
-from jose import jwt
+import jwt
 
 from media_platform.auth.token import Token
 
@@ -8,7 +8,7 @@ def sign_jwt(token: Token, secret: str) -> str:
 
 
 def decode_jwt(shared_secret: str, urn: str, signed_token: str) -> Token:
-    claims = jwt.decode(signed_token, shared_secret, subject=urn, options={
+    claims = jwt.decode(signed_token, shared_secret, algorithms=['HS256'], subject=urn, options={
         'verify_aud': False
     })
 
